<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace KangaPay\Configuration;

class ApiConfiguration extends ModuleConfiguration {
    public function getSubmitAction() {
      return 'APIbtn';
    }

    public function getConfigFields() {
        return ['KANGA_PAY_API', 'KANGA_PAY_SECRET', 'KANGA_PAY_DEVEL', 'KANGA_PAY_MODE', 'KANGA_PAY_OVERPAYMENT', 'KANGA_PAY_SHOW_FEE', 'KANGA_PAY_PREV_PAYMENTS'];
    }

    public function getFieldsForm($module) {
        return [
            'form' => [
                'legend' => [
                    'title' => $module->l('Api details')
                ],
                'input' => [
                    [
                        'type' => 'text',
                        'label' => $module->l('API key'),
                        'name' => 'KANGA_PAY_API',
                        'required' => true,
                        'desc' => $module->l('Go to the payment gateway configuration page in Kanga Exchange and copy the API KEY field.')
                    ],
                    [
                        'type' => 'text',
                        'label' => $module->l('API Secret'),
                        'desc' => $module->l('Go to the payment gateway configuration page in Kanga Exchange and copy the API SECRET field.'),
                        'name' => 'KANGA_PAY_SECRET',
                        'required' => true
                    ],
                    [
                        'type' => 'switch',
                        'label' => $module->l('Devel runtime environment'),
                        'name' => 'KANGA_PAY_DEVEL',
                        'is_bool' => true,
                        'desc' => $module->l('If the switch is on, operations will be performed on the test version of the exchange.'),
                        'values' => [
                            [
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $module->l('Devel'),
                            ],
                            [
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $module->l('Production'),
                            ]
                        ],
                    ],
                    [
                        'type' => 'switch',
                        'label' => $module->l('Analyze abandoned payments'),
                        'name' => 'KANGA_PAY_PREV_PAYMENTS',
                        'is_bool' => true,
                        'default' => true,
                        'desc' => $module->l('If the switch is on, the plugin will analyze previously abandoned payments during each successful payment.'),
                        'values' => [
                            [
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $module->l('Yes'),
                            ],
                            [
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $module->l('No'),
                            ]
                        ],
                    ],
                ],
                'submit' => [
                    'title' => $module->l('Save'),
                ]
            ],
        ];
    }

    protected function doValidation($module) {
        $postErrors = [];

        if (!\Tools::getValue('KANGA_PAY_API')) {
            $postErrors[] = $module->l('The "API KEY" field is required.');
        } elseif (!\Tools::getValue('KANGA_PAY_SECRET')) {
            $postErrors[] = $module->l('The "API Secret" field is required.');
        }

        return $postErrors;
    }

}
