<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace KangaPay\Configuration;

abstract class ModuleConfiguration {

    abstract function getSubmitAction();
    abstract function getConfigFields();
    abstract function getFieldsForm($module);

    protected function doValidation($module) {
        return [];
    }

    public function getFieldsValues() {
        $fieldValues = [];

        foreach ($this->getConfigFields() as $configKey) {
            $fieldValues[$configKey] = \Tools::getValue($configKey, \Configuration::get($configKey));
        }

        return $fieldValues;
    }

    public function renderForm($module) {
        $helper = new \HelperForm();
        $helper->show_toolbar = false;
        $helper->id = (int)\Tools::getValue('id_carrier');
        // $helper->identifier = $module->identifier;

        $helper->submit_action = $this->getSubmitAction();
        $helper->currentIndex = \Context::getContext()->link->getAdminLink('AdminModules', false).'&configure='.$module->name.'&tab_module='.$module->tab.'&module_name='.$module->name;
        $helper->token = \Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = ['fields_value' => $this->getFieldsValues()];

        return $helper->generateForm([$this->getFieldsForm($module)]);
    }

    public function validation($module) {
        if (\Tools::isSubmit($this->getSubmitAction())) {
            return $this->doValidation($module);
        }

        return [];
    }

    public function saveConfiguration() {
        foreach ($this->getConfigFields() as $configKey) {
            \Configuration::updateValue($configKey, \Tools::getValue($configKey));
        }
    }

    public function uninstall() {
        foreach ($this->getConfigFields() as $configKey) {
            \Configuration::deleteByName($configKey);
        }

        return true;
    }

}
