<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace KangaPay;

class Curl {
    private $curl;
    private $info;
    private $active = false;

    public function __construct($url) {
        if ($this->checkExtension() == false) {
            throw new \RuntimeException('curl');
        }

        $this->curl = curl_init($url);

        if ($this->curl !== null) {
            $this->active = true;
        }
    }

    public function __destruct() {
        if ($this->active) {
            $this->close();
            $this->active = false;
        }
    }

    public function addOption($option, $value) {
        curl_setopt($this->curl, $option, $value);
        return $this;
    }

    public function exec() {
        $response = curl_exec($this->curl);
        $this->info = curl_getinfo($this->curl);
        return $response;
    }

    public function error() {
        return curl_error($this->curl);
    }

    public function getInfo() {
        return $this->info;
    }

    public function close() {
        curl_close($this->curl);
        $this->curl = null;
        $this->active = false;
        return $this;
    }

    public function reset() {
        curl_close($this->curl);
        $this->curl = curl_init();
        return $this;
    }

    protected function checkExtension() {
        return extension_loaded('curl');
    }
}
