<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace KangaPay;

class Integration {
  private function __construct() {}

  public static function setShopInformation( ShopConfiguration $shop ) {
    $shop->setShopInformation( self::sendWithApiSig(
      self::getApiUrl( $shop, '/v2/tpg/shop/get' ),
      array( 'appId' => $shop->getAppId() ),
      $shop->getSecret()
    ) );
  }

  public static function checkPayment( ShopConfiguration $shop, $paymentId ) {
    return self::sendWithApiSig(
      self::getApiUrl($shop, '/v2/pay/payment/get'),
      array(
        'appId' => $shop->getAppId(),
        'id' => $paymentId
      ),
      $shop->getSecret()
    );
  }

   static function sendWithApiSig( $url, array $data, $secret ) {
      $curl = new Curl( $url );
      $jsonData = json_encode( self::completedData( $data ) );

      $response = $curl->addOption( CURLOPT_SSL_VERIFYHOST, false )
        ->addOption( CURLOPT_SSL_VERIFYPEER, false )
        ->addOption( CURLOPT_POST, true )
        ->addOption( CURLOPT_RETURNTRANSFER, true )
        ->addOption( CURLOPT_FOLLOWLOCATION, true )
        ->addOption( CURLOPT_HTTPHEADER, array(
          'Content-Type: application/json',
          'api-sig: ' . self::generateApiSig( $jsonData, $secret ),
        ) )
        ->addOption( CURLOPT_POSTFIELDS, $jsonData )
        ->exec();

      $curl->close();

      return json_decode( $response, true );
  }

  private static function send( $url, array $data ) {
    $curl = new Curl( $url );
    $jsonData = json_encode( $data );

    $response = $curl->addOption( CURLOPT_SSL_VERIFYHOST, false )
      ->addOption( CURLOPT_SSL_VERIFYPEER, false )
      ->addOption( CURLOPT_POST, true )
      ->addOption( CURLOPT_RETURNTRANSFER, true )
      ->addOption( CURLOPT_FOLLOWLOCATION, true )
      ->addOption( CURLOPT_HTTPHEADER, array( 'Content-Type: application/json' ) )
      ->addOption( CURLOPT_POSTFIELDS, $jsonData )
      ->exec();

    $curl->close();

    return json_decode( $response, true );
  }

  private static function getApiUrl( ShopConfiguration $shop, $apiUrl ) {
      return $shop->getApiEnvHost() . '/api' . $apiUrl;
  }

  public static function generateApiSig( $jsonData, $secret ) {
      return hash_hmac( 'sha512', $jsonData, $secret );
  }

  private static function completedData( array $data ) {
      $data[ 'nonce' ] = time();
      return $data;
  }
}
