<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace KangaPay;

class OrderStatus {

    const KANGA_PAY_WAITING_STATUS = 'KANGA_PAY_WAITING_STATUS';
    const KANGA_PAY_DONE_STATUS = 'KANGA_PAY_DONE_STATUS';

    public static function installKangaPayStatuses() {
        $numOfStatuses = \Db::getInstance()->getValue('SELECT COUNT(id_order_state) FROM `' . pSQL(_DB_PREFIX_) . 'order_state` WHERE module_name = "kangapay"', false);

        if ($numOfStatuses) {
            return self::getKangaPayStatusesFromDb();
        } else {
            self::addWaitingStatus();
            self::addDoneStatus();
            return true;
        }
    }

    public static function addWaitingStatus() {
        return self::addKangaPayOrderStatus(
            self::KANGA_PAY_WAITING_STATUS,
            'Oczekuje na potwierdzenie płatności w Kanga Pay',
            'Awaiting for Kanga Pay Payment confirmation',
            '#4169E1'
        ) !== false;
    }

    public static function addDoneStatus() {
        return self::addKangaPayOrderStatus(
            self::KANGA_PAY_DONE_STATUS,
            'Płatności potwierdzona przez Kanga Pay',
            'Payment confirmation by Kanga Pay',
            '#32CD32'
        ) !== false;
    }

    public static function getStatus($configKey) {
        return \Configuration::get($configKey);
    }

    private static function getKangaPayStatusesFromDb() {
        $prevStatuses = \Db::getInstance()->executeS('SELECT id_order_state FROM `' . pSQL(_DB_PREFIX_) . 'order_state` WHERE module_name = "kangapay" ORDER BY id_order_state');

        if (!is_array($prevStatuses)) {
            $prevStatuses = $prevStatuses->fetch();
        }

        \Configuration::updateValue(self::KANGA_PAY_WAITING_STATUS, $prevStatuses[0]['id_order_state']);
        \Configuration::updateValue(self::KANGA_PAY_DONE_STATUS, $prevStatuses[1]['id_order_state']);

        return \Configuration::get(self::KANGA_PAY_WAITING_STATUS) && \Configuration::get(self::KANGA_PAY_DONE_STATUS);
    }

    private static function addKangaPayOrderStatus($configKey, $plName, $engName, $color) {
        $newOrderState = new \OrderState();
        $newOrderState->name = array();
        $newOrderState->module_name = 'kangapay';
        $newOrderState->send_email = false;
        $newOrderState->invoice = false;
        $newOrderState->unremovable = false;
        $newOrderState->color = $color;

        foreach (\Language::getLanguages() as $language) {
            if (\Tools::strtolower($language['iso_code']) == 'pl') {
                $newOrderState->name[$language['id_lang']] = $plName;
            } else {
                $newOrderState->name[$language['id_lang']] = $engName;
            }
        }

        if (!$newOrderState->add()) {
            return false;
        }

        \Configuration::updateValue($configKey, $newOrderState->id);

        return $newOrderState->id;
    }

    private function __construct() {}

}
