<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace KangaPay;

class Payment {
  const DEFAULT_CHECK_PAYMENT_ATTEMPTS = 1;

  private function __construct() {}

  public static function checkPayment(ShopConfiguration $shop, $paymentId, $attempts = self::DEFAULT_CHECK_PAYMENT_ATTEMPTS) {
    $sleepSecs = 0;

    do {
      sleep($sleepSecs++);
      $result = Integration::checkPayment($shop, $paymentId);
    } while ($sleepSecs <= $attempts && $result != null && $result['result'] !== 'fail' && !in_array($result['state'], ['SETTLED', 'CANCELED', 'FAILED']));

    return $result;
  }

  public static function confirmPayment(ShopConfiguration $shop, \Order $order) {
    $orderStatus = $order->getCurrentState();
    $kangaPayOrders = \Db::getInstance()->executeS( 'SELECT * FROM ' . pSQL(_DB_PREFIX_) . 'order_kangapay WHERE id_order=' . $order->id );
    $kangaPayOrder = $kangaPayOrders[ 0 ];

    if ($orderStatus == OrderStatus::getStatus( OrderStatus::KANGA_PAY_DONE_STATUS )) {
      $paymentCheck[ 'state' ] = 'SETTLED';
      return $paymentCheck;
    }

    $paymentCheck = self::checkPayment( $shop, $kangaPayOrder[ 'paymentId' ] );
    $status = OrderStatus::getStatus( OrderStatus::KANGA_PAY_WAITING_STATUS );

    if ($paymentCheck == null) return array( 'state' => 'UNKNOWN' );
    if ($paymentCheck[ 'result' ] == 'fail') {
      $status = \Configuration::get( 'PS_OS_CANCELED' );
      $paymentCheck['state'] = 'CANCELED';

      self::updateStatus( $paymentCheck, $order->id );
    } else switch ($paymentCheck[ 'state' ]) {
      case 'SETTLED':
        $status = OrderStatus::getStatus( OrderStatus::KANGA_PAY_DONE_STATUS );

        try {
          \Db::getInstance()->execute( ''
            . ' UPDATE `' . pSQL(_DB_PREFIX_) . 'order_kangapay`'
            . ' SET `state` = \'' . $paymentCheck['state'] . '\''
            . ' WHERE `id_order` = ' . $order->id
          );
        } catch (\Symfony\Component\Debug\Exception\ContextErrorException $e) {
            $paymentCheck[ 'state' ] = 'SETTLED';
        }

        break;

      case 'EXPIRED':
        $status = OrderStatus::getStatus( 'PS_OS_CANCELED' );
        self::updateStatus( $paymentCheck, $order->id );
        break;

      case 'FAILED_CONFIRMATION':
        $status = OrderStatus::getStatus( 'PS_OS_ERROR' );
        self::updateStatus( $paymentCheck, $order->id );

      case 'FAILED_PROCESSING':
        $status = OrderStatus::getStatus( 'PS_OS_ERROR' );
        self::updateStatus( $paymentCheck, $order->id );

      case 'FAILED_SETTLEMENT':
        $status = OrderStatus::getStatus( 'PS_OS_ERROR' );
        self::updateStatus( $paymentCheck, $order->id );
        break;
    }

    if ($orderStatus == OrderStatus::getStatus( OrderStatus::KANGA_PAY_WAITING_STATUS )) {
      $order->setCurrentState( $status );
    }

    return $paymentCheck;
  }

  public static function checkPreviousOrders( ShopConfiguration $shop ) {
    $prevOrders = \Db::getInstance()->executeS(
      'SELECT id_order FROM `' . pSQL(_DB_PREFIX_) . 'order_kangapay` WHERE state IS NULL'
    );

    foreach ($prevOrders as $row) {
      self::confirmPayment( $shop, new \Order( $row[ 'id_order' ] ) );
    }

    return $prevOrders;
  }

  private static function updateStatus( array $paymentCheck, $orderId ) {
    \Db::getInstance()->execute( ''
        . 'UPDATE `' . pSQL(_DB_PREFIX_) . 'order_kangapay` '
        . 'SET `state` = \'' . $paymentCheck['state'] . '\''
        . ' WHERE `id_order` = ' . $orderId
    );
  }
}
