<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace KangaPay\Payment;

abstract class Method {
    const ON_CHAIN = 'on-chain';
    const OFF_CHAIN = 'off-chain';
    const FIAT = 'fiat';

    public static function all() {
        return [self::ON_CHAIN, self::OFF_CHAIN, self::FIAT];
    }

    public static function config($module) {
        return [
            self::OFF_CHAIN => ['name' => $module->l('Kanga Exchange'), 'desc' => $module->l('Instant internal transfer from your Kanga Exchange account'), 'configKey' => 'KANGA_PAY_OFF_CHAIN'],
            self::ON_CHAIN => ['name' => $module->l('External wallet'), 'desc' => $module->l('Regular transfer from an external cryptocurrency wallet'), 'configKey' => 'KANGA_PAY_ON_CHAIN'],
            self::FIAT => ['name' => $module->l('Bank transfer'), 'desc' => $module->l('Fast payment by online bank transfer'), 'configKey' => 'KANGA_PAY_FIAT']
        ];
    }

    public static function configKeys() {
        return ['KANGA_PAY_ON_CHAIN', 'KANGA_PAY_OFF_CHAIN', 'KANGA_PAY_FIAT'];
    }
}
