<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace KangaPay;

class ShopConfiguration {

    const DEFAULT_SHOP_FEE_RATE = 0.03;

    const ENV_URL = [
      'DEVEL'       => 'https://trade.kanga.dev',
      'PRODUCTION'  => 'https://trade.kanga.exchange'
    ];

    const API_ENV_URL = [
      'DEVEL'       => 'https://api.kanga.dev',
      'PRODUCTION'  => 'https://api.kanga.exchange'
    ];


    private $appId;
    private $secret;
    private $devel;
    private $shopFeeRate = self::DEFAULT_SHOP_FEE_RATE;
    private $prevPayments = true;

    public function __construct( $appId, $secret, $devel, $prevPayments ) {
      $this->appId = $appId;
      $this->secret = $secret;
      $this->devel = $devel;
      $this->prevPayments = $prevPayments;
    }

    public function setShopInformation( $kangaData ) {
      if ($kangaData[ 'result' ] === "ok") {
        $this->shopFeeRate = (float) $kangaData[ 'feeRate' ];
      }
    }

    public function getAppId() {
      return $this->appId;
    }

    public function getSecret() {
      return $this->secret;
    }

    public function getShopName() {
      return \Configuration::get('PS_SHOP_NAME');
    }

    public function getNotificationUrl( $cartId, $orderRef ) {
      return \Context::getContext()->link->getModuleLink( 'kangapay', 'notification', array( 'cartId' => $cartId, 'oref' => $orderRef ) );
    }

    public function getCheckUrl( $orderRef ) {
      return \Context::getContext()->link->getModuleLink( 'kangapay', 'checknow', array( 'oref' => $orderRef ) );
    }

    public function getEnv() {
      return $this->devel ? 'DEVEL' : 'PRODUCTION';
    }

    public function getEnvHost() {
      return self::ENV_URL[$this->getEnv()];
    }

    public function getApiEnvHost() {
      return self::API_ENV_URL[$this->getEnv()];
    }

    public function getShopFeeRate() {
      return $this->shopFeeRate;
    }

    public function isPrevPayments() {
      return $this->prevPayments;
    }

    public static function fromConfiguration(array $config) {
      return new ShopConfiguration(
        $config[ 'KANGA_PAY_API'],
        $config[ 'KANGA_PAY_SECRET' ],
        $config[ 'KANGA_PAY_DEVEL' ],
        $config[ 'KANGA_PAY_PREV_PAYMENTS' ]
      );
    }

    public static function fromDefaultConfiguration() {
      return self::fromConfiguration( \Configuration::getMultiple([
        'KANGA_PAY_API',
        'KANGA_PAY_SECRET',
        'KANGA_PAY_DEVEL',
        'KANGA_PAY_PREV_PAYMENTS'
      ]) );
    }
}
