<?php
/**
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 *
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to tech@dotpay.pl so we can send you a copy immediately.
 *
 * @author    Paweł Stolarski <pstolarski@kanga.exchange>
 * @copyright Kanga Exchange
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

class KangaPayValidationModuleFrontController extends ModuleFrontController {
  public function postProcess() {
    $this->validateControllerWork();

    $cart     = $this->context->cart;
    $shop     = KangaPay\ShopConfiguration::fromDefaultConfiguration();
    $customer = new Customer( $cart->id_customer );
    $orderRef = Order::generateReference();

    $kangaPayData = array(
      'appId'               => $shop->getAppId(),
      'itemPrice'           => '' . (float) $cart->getOrderTotal( true, Cart::BOTH ),
      'itemCurrency'        => 'o' . $this->context->currency->iso_code,
      'destinationCurrency' => 'o' . $this->context->currency->iso_code,
      'payCode'             => Tools::getValue( 'paycode' ),
      'paymentId'           => $orderRef,
      'paymentDescription'  => '',
      'notificationUrl'     => $shop->getNotificationUrl( $cart->id, $orderRef ),
    );

    $response = \KangaPay\Integration::sendWithApiSig(
      $shop->getApiEnvHost() . '/api/v2/pay/payment/create',
      $kangaPayData,
      $shop->getSecret(),
    );

    if ($response == null) {
      return Tools::redirect('index.php?controller=order&step=1&err=2');
      // echo json_encode( array( 'message' => 'Internal server error; invalid body' ) );
      // die;
    }

    if ($response[ 'result' ] == 'fail') {
      if ($response['code'] == 9001) {
        return Tools::redirect('index.php?controller=order&step=1&err=4');
      }

      if ($response['code'] == 9005) {
        return Tools::redirect('index.php?controller=order&step=1&err=6');
        $response['message'] = 'Internal server error; PaymentId not unique';
      }

      return Tools::redirect('index.php?controller=order&step=1&err=8');
    }

    $this->module->validateOrder(
        (int) $cart->id,
        \KangaPay\OrderStatus::getStatus( \KangaPay\OrderStatus::KANGA_PAY_WAITING_STATUS ),
        $kangaPayData[ 'itemPrice' ],
        $this->module->displayName,
        null,
        [],
        (int)$this->context->currency->id,
        false,
        $customer->secure_key,
        null,
        $orderRef,
    );

    $paymentData = new KangaPay\Payment\Data();
    $paymentData->orderId = $this->module->currentOrder;
    $paymentData->paymentId = $response[ 'id' ];

    $this->dbOrderUpdate( $paymentData );

    $redirect = $this->context->shop->getBaseURL(true) . 'index.php?' . http_build_query( array(
      'controller' => 'order-confirmation',
      'id_cart' => $cart->id,
      'id_module' => $this->module->id,
      'module' => 'kangapay',
      'key' => $customer->secure_key,
      'oid' => $paymentData->orderId,
    ) );

    // echo json_encode( array(
    //   'kangaPayData' => $kangaPayData,
    //   'paymentData' => $paymentData,
    //   'response' => $response,
    //   'paymentId' => $response['id'],
    //   'orderRef' => $orderRef,
    //   'next' => $redirect,
    // ) );

    Tools::redirect( $redirect );
    die;
  }

  private function validateControllerWork() {
    $cart = $this->context->cart;

    if ($cart->id_customer == 0 || $cart->id_address_delivery == 0 || $cart->id_address_invoice == 0 || !$this->module->active) {
      Tools::redirect( 'index.php?controller=order&step=1' );
      return;
    }

    $authorized = false;

    foreach (Module::getPaymentModules() as $module) {
      if ($module[ 'name' ] == 'kangapay') {
        $authorized = true;
        break;
      }
    }

    if (!$authorized) {
      die( $this->module->l( 'This payment method is not available.', 'validation' ) );
    }

    $customer = new Customer( $cart->id_customer );

    if (!Validate::isLoadedObject( $customer )) {
      Tools::redirect( 'index.php?controller=order&step=1' );
      return;
    }
  }

  private function dbOrderUpdate(KangaPay\Payment\Data $paymentData) {
    Db::getInstance()->execute( 'INSERT INTO `' . pSQL(_DB_PREFIX_) . 'order_kangapay` SET'
      . '  `id_order` = ' . $paymentData->orderId
      . ', `state` = \'NEW\''
      . ', `paymentId` = \'' . $paymentData->paymentId . '\''
    );
  }
}
